pub struct ProviderV2StartRequest {
pub options: StartOptions,
}Fields
options: StartOptionsTrait Implementations
Sourceimpl Clone for ProviderV2StartRequest
impl Clone for ProviderV2StartRequest
Sourcefn clone(&self) -> ProviderV2StartRequest
fn clone(&self) -> ProviderV2StartRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ProviderV2StartRequest
impl Debug for ProviderV2StartRequest
Sourceimpl<D: ResourceDialect> Decode<ProviderV2StartRequest, D> for ProviderV2StartRequest
impl<D: ResourceDialect> Decode<ProviderV2StartRequest, D> for ProviderV2StartRequest
Sourceimpl<D: ResourceDialect> Encode<ProviderV2StartRequest, D> for &ProviderV2StartRequest
impl<D: ResourceDialect> Encode<ProviderV2StartRequest, D> for &ProviderV2StartRequest
Sourceimpl<D: ResourceDialect, T0: Encode<StartOptions, D>> Encode<ProviderV2StartRequest, D> for (T0,)
impl<D: ResourceDialect, T0: Encode<StartOptions, D>> Encode<ProviderV2StartRequest, D> for (T0,)
Sourceimpl Hash for ProviderV2StartRequest
impl Hash for ProviderV2StartRequest
Sourceimpl Ord for ProviderV2StartRequest
impl Ord for ProviderV2StartRequest
Sourcefn cmp(&self, other: &ProviderV2StartRequest) -> Ordering
fn cmp(&self, other: &ProviderV2StartRequest) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for ProviderV2StartRequest
impl PartialEq for ProviderV2StartRequest
Sourceimpl PartialOrd for ProviderV2StartRequest
impl PartialOrd for ProviderV2StartRequest
Sourceimpl TypeMarker for ProviderV2StartRequest
impl TypeMarker for ProviderV2StartRequest
Sourcetype Owned = ProviderV2StartRequest
type Owned = ProviderV2StartRequest
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for ProviderV2StartRequest
impl ValueTypeMarker for ProviderV2StartRequest
Sourcetype Borrowed<'a> = &'a ProviderV2StartRequest
type Borrowed<'a> = &'a ProviderV2StartRequest
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreimpl Eq for ProviderV2StartRequest
impl Persistable for ProviderV2StartRequest
impl StructuralPartialEq for ProviderV2StartRequest